import vtk

#-----------------------------------
# Build rendering facilities
#-----------------------------------

# Make a window
renwin = vtk.vtkRenderWindow()
renwin.SetSize(500,500)

# Make a renderer for that window
renderer = vtk.vtkRenderer()
renwin.AddRenderer(renderer)

# Control how it all looks
renderer.SetBackground2(1,1,1)
renderer.SetGradientBackground(1)

# Show it
renwin.Render()

# Access the data processing pipeline that has your data
mapper = vtk.vtkDataSetMapper()
mapper.ScalarVisibilityOff()

# Link that the the display system
actor = vtk.vtkActor()
actor.SetMapper(mapper)
renderer.AddViewProp(actor)

#-----------------------------------
# Build structured grid
#-----------------------------------

p = vtk.vtkPoints()
p.InsertNextPoint( 0,0,0 )
p.InsertNextPoint( 1,0,0 )
p.InsertNextPoint( 0,1,0 )
p.InsertNextPoint( 1,1,0 )
p.InsertNextPoint( 0,0,1 )
p.InsertNextPoint( 1,0,1 )
p.InsertNextPoint( 0,1,1.5 )
p.InsertNextPoint( 1,1,2   )

sg = vtk.vtkStructuredGrid()
sg.SetDimensions (2,2,2)
sg.SetPoints(p)

fa = vtk.vtkFloatArray()

for i in range(0,8):
   fa.InsertValue( i, i )

fa.SetValue(0,7)
   
sg.GetPointData().SetScalars( fa )

#-----------------------------------
# Show point values as glyphs
#-----------------------------------

ss = vtk.vtkSphereSource()
ss.SetRadius(0.2)

gf = vtk.vtkGlyph3D()
gf.SetScaleModeToDataScalingOff()
gf.SetInput(sg)
gf.SetSource(ss.GetOutput())

mapper.SetInputConnection(gf.GetOutputPort())
mapper.ScalarVisibilityOn()
mapper.SetScalarRange(fa.GetRange())
renderer.ResetCamera()
renwin.Render()

#-----------------------------------
# Show point values on structured points output surface
#-----------------------------------

#dssf = vtk.vtkDataSetSurfaceFilter()
#dssf.SetInput(sg)
#mapper.SetInputConnection(dssf.GetOutputPort())
#renwin.Render()

#-----------------------------------
# Show point values on structured points output surface
#-----------------------------------
iren = vtk.vtkRenderWindowInteractor()
renwin.SetInteractor(iren)
iren.Initialize()
iren.Start()