#-----------------------------------
#Exercise: Help function
#-----------------------------------

import vtk

def list_dir(x):
    for item in dir(x):
        print item

help(vtk.vtkDoubleArray)

#-----------------------------------
#Exercise: Learn VTK Array
#-----------------------------------

# Make an array
myArray = vtk.vtkDoubleArray() 
list_dir(myArray) 
help(myArray.SetValue) 
print(myArray) 
myArray.SetName('my first array') 
myArray.SetNumberOfComponents(1) 
myArray.SetNumberOfTuples(500*500) #going to make a 500x500 picture 

# Fill it with data 
from math import sin, cos 
for x in range(0,500):
	for y in range(0,500):
		myArray.SetValue(x*500+y, 127.5+(1.0+sin(x/25.0)*cos(y/25.0)))

#-----------------------------------
# Exercise create a vtklmageData and inspect
#-----------------------------------

# PythoniBuildUGrid.py For an example of building an unstructured data set

# Create the Data structure 
id = vtk.vtkImageData() 

# Define its Geometry 
id.SetOrigin(0,0,0) 
id.SetSpacing(1,1,1)

# Define its Topology 
id.SetDimensions(500,500,1) 

# Assign Data to the Structure, Geometry and/or Topology
id.SetScalarType(vtk.VTK_DOUBLE)
id.GetPointData().SetScalars(myArray)

# Inspect it 
print(id)
print(id.GetPointData())
array = id.GetPointData().GetArray('my first array')
array.GetRange()

array = id.GetPointData().GetArray('my first array')
print(array)

#-----------------------------------
# How to display data 
# Slide: VTK Graphics subsystem
# Slide: VTK Rendering Engine
# Slide: VTK RenderWindow
# Slide: vtkRenderer
# Slide: VTK Camera
# Slide: VTK Actor
#-----------------------------------

#-----------------------------------
# Slide: Exercise : Make a window 
#-----------------------------------

# Make a window 
renwin = vtk.vtkRenderWindow() 
renwin.SetSize(500,500) 

# Make a renderer for that window
renderer = vtk.vtkRenderer() 
renwin.AddRenderer(renderer) 

# Control how it all looks 
renderer.SetBackground2(1,1,1) 
renderer.SetGradientBackground(1) 

# Show it 
renwin.Render() 

#-----------------------------------
# Exercise : Show some data 
#-----------------------------------

# Access the data processing pipeline that has your data 
mapper = vtk.vtkDataSetMapper() 
mapper.SetInput(id) 
mapper.ScalarVisibilityOff() # we'll talk about this soon

# Link that the the display system 
actor = vtk.vtkActor() 
actor.SetMapper(mapper) 
renderer.AddViewProp(actor) 
renwin.Render() 

# Adjust the camera for a better view 
renderer.ResetCamera() 
renwin.Render()

actorProperty = actor.GetProperty()
actorProperty.SetDiffuseColor(0,1,1)
renwin.Render()

#-----------------------------------
# Slide : color control by vtkActor and vtkMapper
# Slide : vtkProperty (actor has)
# Slide : vtkMapper (actor also has)
# Slide: vtkLookupTable (mapper has)
#-----------------------------------

#-----------------------------------
# Exercise : Visualize the topology 
#-----------------------------------
# Specify whole Prop color 
actorProperty = actor.GetProperty() 
actorProperty.SetDiffuseColor(0,1,1) 
renwin.Render() 

# Change from surface to edges rendering 
actorProperty.SetRepresentationToWireframe() 
renwin.Render() 
renderer.GetActiveCamera().Zoom(10) 
renwin.Render() 

# Reset
actorProperty.SetRepresentationToSurface()
renderer.ResetCamera() 

#-----------------------------------
# Exercise: visualize the arrays 
#-----------------------------------
# Turn on color from values 
mapper.ScalarVisibilityOn()
renwin.Render()

# Match up lookuptable range
myArray.GetRange()
mapper.SetScalarRange(127,129)
renwin.Render()


#-----------------------------------
# Slide: Alghoritms
# Slide: Example Alghoritms
#-----------------------------------

#-----------------------------------
# Exercise : read a data file, inspect and visualize
#-----------------------------------
# Create a reader, tell it what file and run it
reader = vtk.vtkDataSetReader()
reader.SetFileName("c:\Devel\VTKSchool\codeAndData\SaintHelens.vtk")

# Examine the result 
id = reader.GetOutput()	
print id.GetPointData().GetArray(0)
reader.Update()
print id.GetPointData().GetArray(0).GetRange()
mapper.SetInputConnection(reader.GetOutputPort())
mapper.SetScalarRange(682.0, 2543.0)
renwin.Render()
renderer.ResetCamera()
renwin.Render() 

#-----------------------------------
# Slide : pipeline execution model
# Slide: demand driven pipeline
#-----------------------------------

#-----------------------------------
# Exercise : manipulate the read in data 
#-----------------------------------
# Make filter to convert to a less constrained data structure 
triangles = vtk.vtkDataSetTriangleFilter() 

#Connect it 
triangles.SetInputConnection(reader.GetOutputPort()) 

#Run it
triangles.Update() 
print(reader.GetOutput().GetClassName()) 
print(triangles.GetOutput().GetClassName()) 

#-----------------------------------
# Exercise : manipulate the read in data 
#-----------------------------------

# Make and use a filter to change the geometry 
warp = vtk.vtkWarpScalar() 
warp.SetInputConnection(triangles.GetOutputPort()) 
warp.Update() 
print(triangles.GetOutput().GetBounds()) 
print(warp.GetOutput().GetBounds()) 

# Show it 
mapper.SetInputConnection(warp.GetOutputPort())
renwin.Render() 

#-----------------------------------
# Exercise : manipulate the data 
#-----------------------------------
# Make a clip filter and put it in pipeline 
clip = vtk.vtkClipDataSet() 
clip.SetInputConnection(warp.GetOutputPort())
mapper.SetInputConnection(clip.GetOutputPort()) 

# Make a source to orient clip filter with 
plane = vtk.vtkPlane() 
clip.SetClipFunction(plane) 
plane.SetOrigin(560000,5120000,2000) 

# Inspect the result
clip.Update() 
print clip.GetOutput().GetBounds()

#-----------------------------------
# Slide : interaction 
#-----------------------------------

#-----------------------------------
# Exercise: use a widget to interact with the data 
#-----------------------------------
# Get a hold of window events 
iren = vtk.vtkRenderWindowInteractor() 

renwin.SetInteractor(iren) 
# Make and initially place the widget
widget = vtk.vtkImplicitPlaneWidget()
widget.PlaceWidget(warp.GetOutput().GetBounds()) 
widget.SetOrigin([plane.GetOrigin()[x] for x in 0,1,2]) 
widget.SetNormal([plane.GetNormal()[x] for x in 0,1,2]) 

# Connect it to the renderwindow's events 
widget.SetInteractor(iren) 

#-----------------------------------
# Exercise: use a widget to interact with the data 
#-----------------------------------

# Connect the widget's events to our pipeline 
def eventhandler(obj , event): 
	global plane 
	obj.GetPlane(plane) 

widget.AddObserver("InteractionEvent", eventhandler) 

# Configure the widget 
widget.SetEnabled(1) 
widget.DrawPlaneOn() 
widget.TubingOn() 

# Turn on interaction 
iren.Initialize() 
renwin.Render() 
iren.Start() 
