import vtk

#-----------------------------------
# Build rendering facilities
#-----------------------------------

# Make a window 
renwin = vtk.vtkRenderWindow() 
renwin.SetSize(500,500) 

# Make a renderer for that window
renderer = vtk.vtkRenderer() 
renwin.AddRenderer(renderer) 

# Control how it all looks 
renderer.SetBackground2(1,1,1) 
renderer.SetGradientBackground(1) 

# Show it 
renwin.Render() 

# Access the data processing pipeline that has your data 
mapper = vtk.vtkDataSetMapper() 
mapper.ScalarVisibilityOff()

# Link that the the display system 
actor = vtk.vtkActor() 
actor.SetMapper(mapper) 
renderer.AddViewProp(actor) 

#-----------------------------------
# Build structured points
#-----------------------------------

sp = vtk.vtkStructuredPoints()
sp.SetOrigin    (0,0,0)
sp.SetDimensions(3,3,3)
sp.SetSpacing   (1,1,1)

fa = vtk.vtkFloatArray()
for i in range(0,27):
   fa.InsertValue( i, i )

sp.GetPointData().SetScalars( fa )

#-----------------------------------
# Show point values as glyphs
#-----------------------------------

ss = vtk.vtkSphereSource()
ss.SetRadius(0.2)

gf = vtk.vtkGlyph3D()
gf.SetScaleModeToDataScalingOff()
gf.SetInput(sp)
gf.SetSource(ss.GetOutput())

mapper.SetInputConnection(gf.GetOutputPort())
mapper.ScalarVisibilityOn()
mapper.SetScalarRange(fa.GetRange())
renderer.ResetCamera()
renwin.Render()

#-----------------------------------
# Show point values on structured points output surface
#-----------------------------------

dssf = vtk.vtkDataSetSurfaceFilter()
dssf.SetInput(sp)
mapper.SetInputConnection(dssf.GetOutputPort())
renwin.Render()

#-----------------------------------
# Exercise: do the same for the rectilinear grid in the power point 
#-----------------------------------
